| genotypeFasta | R Documentation |
genotypeFasta converts a genotype table into a vector of nucleotide
sequences.
genotypeFasta(
genotype,
germline_db,
novel = NA,
include_unseen = FALSE,
strip_d = TRUE
)
genotype |
|
germline_db |
vector of named nucleotide germline sequences
matching the alleles detailed in |
novel |
an optional |
include_unseen |
if |
strip_d |
if |
A named vector of strings containing the germline nucleotide sequences of the alleles in the provided genotype.
inferGenotype
# Find the sequences that correspond to the genotype
genotype_db <- genotypeFasta(SampleGenotype, SampleGermlineIGHV, SampleNovel)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.